<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Agenda;
use DataTables;
use Validator;
use Auth;


use DB;
class AgendaController extends Controller
{ 
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function listar(Request $request,$agenda)
    {
        //return $agenda;
        if($agenda=="agenda alcaldia")
            $query = Agenda::with('user')->where('tipo','alcaldia')->get();        
        if($agenda=="gerente")
            $query = Agenda::with('user')->where('tipo','gerencia')->get();

        return DataTables::of($query)->toJson();
    }

    public function nuevo(Request $request)
    {        
        $validator = Validator::make($request->all(), [              
            'titulo' => 'required',
            'descripcion' => 'required',
            'lugar' => 'required',
            'fecha' => 'required',
            'inicio' => 'required',
            'fin' => 'required',         
            'estado' => 'required'      
        ]);
    
        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {
            $user = Auth::user();
            $input = $request->all(); 
            
            $item = new Agenda;
            if($user->tipo=="3")
                $item->tipo = $user->tipo=="3"? "alcaldia":"gerencia";
                if($user->tipo=="4")
                $item->tipo = $user->tipo=="3"? "alcaldia":"gerencia";
            if($user->tipo=="1" ||$user->tipo=="2")
                $item->tipo = $input["tipo"]=="agenda alcaldia"? "alcaldia":"gerencia";            
            
            $item->titulo = $input["titulo"];
            $item->descripcion = $input["descripcion"];
            $item->lugar = $input["lugar"];
            $item->fecha = $input["fecha"];
            $item->inicio = $input["inicio"];
            $item->fin = $input["fin"];
            $item->estado = $input["estado"];
            $item->user_id = $user->id;

            if($item->save())
                return response()->json(['data'=>$item, 'message'=>'Registrado correctamente'], 200);
            else 
                return response()->json(['message'=>'No se pudo registrar'], 500);            
        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }

    public function modificar(Request $request, $id)
    {  
        $validator = Validator::make($request->all(), [              
            'titulo' => 'required',
            'descripcion' => 'required',
            'lugar' => 'required',
            'fecha' => 'required',
            'inicio' => 'required',
            'fin' => 'required',   
            'estado' => 'required',   
        ]);

        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {            
            $item = Agenda::find($id);          

            if($item)
            {                
                $user = Auth::user();
                $input = $request->all(); 
                $item->titulo = $input["titulo"];
                $item->descripcion = $input["descripcion"];
                $item->lugar = $input["lugar"];
                $item->fecha = $input["fecha"];
                $item->inicio = $input["inicio"];
                $item->fin = $input["fin"];
                $item->estado = $input["estado"];
                $item->user_id = $user->id;

                if($item->save())
                    return response()->json(['data'=>$item, 'message'=>'Actualizado correctamente'], 200);
                else 
                    return response()->json(['message'=>'No se pudo actualizar'], 500);                
            }
            else
                return response()->json(['message'=>'No se pudo encontrar'], 500);
        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }

    public function eliminar(Request $request, $id)
    {
        $item = Agenda::find($id);
              
        try 
        {
            if($item)
            {
                if($item->delete())
                    return response()->json(['message'=>'Eliminado correctamente'], 200);
                else 
                    return response()->json(['message'=>'No se pudo eliminar'], 500); 
            }
            else
                return response()->json(['message'=>'No se pudo encontrar'], 500);
        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }    
        
    }

}
