<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
//use Illuminate\Support\Str;
use App\Models\User;
use App\Models\Persona;
use App\Models\User_verificacion;
use App\Mail\VerificacionEmail;
use App\Mail\RestablecerEmail;
use DataTables;
use Session;
use Validator;

class UsuarioController extends Controller
{
    //
    //
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function listar(Request $request)
    {        
        $query = User::get();
        return DataTables::of($query)->toJson();
    }

    public function buscar(Request $request)
    { 
        $validator = Validator::make($request->all(), [
            'term' => 'required'
        ]);
    
        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        $result = User::where('estado', 1)//1:interno, 0:externo
        ->where(function ($query) use ($request) {
            $query->where('nro_documento','like', '%'.$request->input('term').'%')
                ->orWhere('nombre','like', '%'.$request->input('term').'%')
                ->orWhere('apaterno','like', '%'.$request->input('term').'%')
                ->orWhere('amaterno','like', '%'.$request->input('term').'%');
        })->get();                              
        return response()->json($result, 200);
    }
    public function estado(Request $request)
    {     
        //return $request;
        $estado=0;
        if($request->estado=="0")
            $estado=1;    
        $noticia=User::find($request->id);         
        $noticia->estado=$estado;
        if($noticia->save())
            return response()->json(['message'=>'Se guardo correctamente'], 200);
        else
            return response()->json(['message'=>'Error, no se guardaron los datos'], 500);
    }

    public function nuevo(Request $request)
    {
        //return $request;
        $validator = Validator::make($request->all(), [ 
            'nombre' => 'required',
            'tipo' => 'required',            
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed']             
        ]);
    
        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {
            
            $input = $request->all(); 
            $user = new User;
            $user->tipo = $input['tipo'];
            $user->nro_documento = $request->documento;
            $user->nombre = $input['nombre'];
            $user->email = $input['email'];            
            $user->password = Hash::make($input['password']); 

            if($user->save()){
                //User_verificacion::where('user_id', $user->id)->update(['estado' => 0]);
                //creamos uno nuevo
               // Mail::to($user)->send(new VerificacionEmail($user, $verificacion));
                return response()->json(['data'=>$user, 'message'=>'Registrado correctamente'], 200);
            }
            else 
                return response()->json(['message'=>'No se pudo registrar'], 500);  
          
        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }

    public function modificar(Request $request, $id)
    {        
        $validator = Validator::make($request->all(), [             
            'tipo' => 'required', 
            'estado' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {
            $user = User::find($id);
            $input = $request->all();    

            if($user == null)
                return response()->json(['message'=>'No se pudo encontrar el usuario'], 500); 
                            
            $user->tipo = $input['tipo'];
            $user->estado = $input['estado'];
                                    
            if($user->save())
                return response()->json(['data'=>$user, 'message'=>'Actualizado correctamente'], 200);
            else 
                return response()->json(['message'=>'No se pudo actualizar'], 500);            
        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }

    //uno mismo
    public function actualizar(Request $request)
    {        
        $validator = Validator::make($request->all(), [    
            'nro_documento' => 'required',  
            'nombre' => 'required',  
        ]);

        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {
            $user = Auth::user();
            $input = $request->all();    

            if($user->tipo != null)
                return response()->json(['message'=>'Solo se puden actualizar datos de usuario público.'], 500);
                                
            $user->nro_documento = $input['nro_documento'];
            $user->nombre = $input['nombre'];
                                    
            if($user->save())
                return response()->json(['data'=>$user, 'message'=>'Actualizado correctamente'], 200);
            else 
                return response()->json(['message'=>'No se pudo actualizar'], 500);            
        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }
    
    public function cambiar_password(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'password' => ['required', 'string', 'min:8', 'confirmed']      
        ]);

        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {
            $input = $request->all();
            $user = User::find($id);

            if($user == null)
                return response()->json(['message'=>'No se pudo encontrar'], 500);

            $user->password = Hash::make($input['password']);
            if($user->save())
                return response()->json(['data'=>$user, 'message'=>'Actualizado correctamente'], 200);
            else 
                return response()->json(['message'=>'No se pudo actualizar'], 500);

        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }

    //uno mismo
    public function renovar_password(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password_old' => 'required',
            'password' => ['required', 'string', 'min:8', 'confirmed']      
        ]);

        if ($validator->fails()) {
            return response()->json(['message'=>$validator->errors()], 500);
        }

        try 
        {
            $user = Auth::user();
            $input = $request->all();

            if(Hash::check($input["password_old"], $user->password)) {
                $user->password = Hash::make($input['password']); 
                if($user->save())
                    return response()->json(['message'=>'Actualizado correctamente'], 200);
                else 
                    return response()->json(['message'=>'No se pudo actualizar'], 500);
            }
            else
             return response()->json(['message'=>'La contraseña proporcionada no es la correcta'], 500);

        }
        catch (\Exception $e) {
            return response()->json(['message'=>$e->getMessage()], 500);
        }
    }
}
